==> Flashflood-0.8.5.tar.gz: Flashflood-0.8.5/flashflood/node/reader/sdfile.py <==
#
# (C) 2014-2017 Seiji Matsuoka
# Licensed under the MIT License (MIT)
# http://opensource.org/licenses/MIT
#

import json

from chorus import v2000reader  # , v2000writer
from chorus import molutil
from chorus.draw import calc2dcoords

from flashflood import static
from flashflood.core.node import SyncNode


class SDFileReaderBase(SyncNode):
    def __init__(self, sdf_options=(), implicit_hydrogen=False,
                 recalc_coords=False, fields=None, params=None):
        super().__init__(params=params)
        self.sdf_options = sdf_options
        self.implicit_hydrogen = implicit_hydrogen
        self.recalc_coords = recalc_coords
        self.fields.merge(
            {"key": s, "name": s, "format": "text"} for s in sdf_options)
        self.fields.add(static.MOLOBJ_FIELD)
        if fields is not None:
            self.fields.merge(fields)

    def records_iter(self):
        for mol in self.contents:
            row = {}
            if self.implicit_hydrogen:
                mol = molutil.make_Hs_implicit(mol)
            if self.recalc_coords:
                calc2dcoords.calc2dcoords(mol)
            row["__molobj"] = json.dumps(mol.jsonized())
            for op in self.sdf_options:
                row[op] = mol.data.get(op, "")
            yield row

    def on_submitted(self):
        self._out_edge.records = self.records_iter()
        self._out_edge.fields.merge(self.fields)
        self._out_edge.params.update(self.params)


class SDFileReader(SDFileReaderBase):
    def __init__(self, in_file, **kwargs):
        super().__init__(**kwargs)
        self.contents = v2000reader.mols_from_file(in_file)
        self.row_count = v2000reader.inspect_file(in_file)[1]


class SDFileLinesInput(SDFileReaderBase):
    def __init__(self, lines, **kwargs):
        super().__init__(**kwargs)
        self.contents = v2000reader.mols_from_text(lines)
        self.row_count = v2000reader.inspect_text(lines)[1]

==> Flashflood-0.12.0.tar.gz: Flashflood-0.12.0/flashflood/node/reader/sdfile.py <==
#
# (C) 2014-2017 Seiji Matsuoka
# Licensed under the MIT License (MIT)
# http://opensource.org/licenses/MIT
#

from chorus import v2000reader
from chorus import molutil
from chorus.draw import calc2dcoords

from flashflood import static
from flashflood.node.reader.readerbase import ReaderBase


class SDFileReaderBase(ReaderBase):
    def __init__(self, sdf_options=(), implicit_hydrogen=False,
                 recalc_coords=False, **kwargs):
        super().__init__(**kwargs)
        self.sdf_options = sdf_options
        self.implicit_hydrogen = implicit_hydrogen
        self.recalc_coords = recalc_coords
        if not self.fields:
            self.fields.merge(
                {"key": s, "name": s, "format": "text"} for s in sdf_options)
        self.fields.add(static.MOLOBJ_FIELD)

    def run(self, on_finish, on_abort):
        self._out_edge.send(self.records_iter())
        on_finish()

    def records_iter(self):
        for mol in self.contents:
            row = {}
            if self.implicit_hydrogen:
                mol = molutil.make_Hs_implicit(mol)
            if self.recalc_coords:
                calc2dcoords.calc2dcoords(mol)
            row["__molobj"] = mol
            for op in self.sdf_options:
                row[op] = mol.data.get(op, "")
            yield row


class SDFileReader(SDFileReaderBase):
    def __init__(self, in_file, **kwargs):
        super().__init__(**kwargs)
        self.contents = v2000reader.mols_from_file(in_file)


class SDFileLinesInput(SDFileReaderBase):
    def __init__(self, lines, **kwargs):
        super().__init__(**kwargs)
        self.contents = v2000reader.mols_from_text(lines)
